@@ -1,7 +1,7 @@
 package Perl6::Say::Auxiliary;
 #$Id: Auxiliary.pm 1344 2009-03-16 03:27:56Z jimk $
 # Contains test subroutines for distribution with Perl6::Say
-# As of:  March 16, 2009
+# As of:  March 29, 2009
 use strict;
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -10,10 +10,15 @@ our @EXPORT_OK = qw(
     capture_say
     capture_say_file
     capture_say_scalar
+    $capture_fail_message
 );
 use Carp;
 *is = *Test::More::is;
 
+our $capture_fail_message;
+eval qq{ require IO::CaptureOutput; };
+$capture_fail_message="tests require IO::CaptureOutput" if $@;
+
 sub _validate {
     my $pred = shift;
     croak "2nd argument to capture_STDOUT must be integer"
@@ -31,11 +36,14 @@ sub capture_say {
     }
     my $pred  = $argsref->{pred};
     my $l = _validate($pred);
-    my $capture = IO::Capture::Stdout->new();
-    $capture->start;
-    &{$argsref->{eval}};
-    $capture->stop;
-    my $cat = join q{}, $capture->read();
+    my $cat;
+    #IO::CaptureOutput->import('capture');
+    IO::CaptureOutput::capture(sub { &{$argsref->{eval}}; },\$cat);
+    #my $capture = IO::Capture::Stdout->new();
+    #$capture->start;
+    #&{$argsref->{eval}};
+    #$capture->stop;
+    #my $cat = join q{}, $capture->read();
     unless ($str) {
         $str = join q{}, @list;
     }
